@@ -8,7 +8,7 @@ window.addEvent('domready', function() {
 
     $$("p.alt").each(function(el) {
         el.addEvent('click', function() {
-            val = el.get('text').replace(/\D/g, '');
+            val = el.get('text');
             document.id('id_amount').set('value', val);
             removeSelected();
             el.addClass("active");
